@@ -1,5 +1,5 @@
-# This code is part of Perl distribution OODoc version 3.04.
-# The POD got stripped from this file by OODoc version 3.04.
+# This code is part of Perl distribution OODoc version 3.05.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
 # This software is copyright (c) 2003-2025 by Mark Overmeer.
@@ -8,13 +8,9 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package OODoc::Object;{
-our $VERSION = '3.04';
+our $VERSION = '3.05';
 }
 
 
@@ -61,12 +57,21 @@ sub init($)
 sub unique() { $_[0]->{OO_unique} }
 
 
+sub manual() { panic }
+
+#--------------------
+
 my $index;  # still a global :-(  Set by ::Export
 sub _publicationIndex($) { $index = $_[1] }
 
 sub publish($)
 {	my ($self, $args) = @_;
-	$index->{$self->unique} = +{ id => $self->unique };
+	my $id     = $self->unique;
+
+	my $manual = $args->{manual};
+	$id .= '-' . $manual->unique if $manual->inherited($self);
+
+	$index->{$id} = +{ id => $id };
 }
 
 1;
